<?php
/**
 * Admin class
 *
 * User_Registration_Zapier Admin
 *
 * @package User_Registration_Zapier
 * @since  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'UR_Zapier_Admin' ) ) {
	/**
	 * Admin class.
	 * The class manage all the admin behaviors.
	 *
	 * @since 1.0.0
	 */
	class UR_Zapier_Admin {

		/**
		 * Plugin options
		 *
		 * @var array
		 * @access public
		 * @since 1.0.0
		 */
		public $options = array();

		/**
		 * Plugin version
		 *
		 * @var string
		 * @since 1.0.0
		 */
		public $version = UR_ZAPIER_VERSION;

		/**
		 * Constructor
		 *
		 * @access public
		 * @since 1.0.0
		 */
		public function __construct() {

			// Zapier Settings Hooks.
			if ( is_admin() ) {
				// Hooks for Enble disable zapier in individual form settings.
				add_action( 'user_registration_after_form_settings', array( $this, 'render_zapier_section' ) );
				add_filter( 'user_registration_form_settings_save', array( $this, 'save_zapier_settings' ), 10, 2 );

				add_action( 'user_registration_after_admin_save_profile_validation', array( $this, 'ur_zapier_after_admin_save_profile_validation' ), 10, 2 );
				add_action( 'ur_user_approved', array( $this, 'ur_zapier_after_admin_approval' ) );
			}

		}

		/**
		 * Render Zapier Section.
		 *
		 * @param  int $form_id Form Id.
		 * @return void
		 */
		public function render_zapier_section( $form_id = 0 ) {

			echo '<div id="zapier-settings" ><h3>' . esc_html__( 'Zapier Settings', 'user-registration-zapier' ) . '</h3>';

			// Zapier.
			$arguments = $this->zapier_form_settings( $form_id );

			foreach ( $arguments as $args ) {
				user_registration_form_field( $args['id'], $args );
			}

			echo '</div>';
		}

		/**
		 * Individual Form Settings for Zapier.
		 *
		 * @param int $form_id Form Id.
		 *
		 * @return array $settings
		 */
		public function zapier_form_settings( $form_id ) {

			$arguments = array(
				'form_id'      => $form_id,

				'setting_data' => array(
					array(
						'type'              => 'checkbox',
						'label'             => __( 'Enable Zapier', 'user-registration-zapier' ),
						'description'       => '',
						'required'          => false,
						'id'                => 'user_registration_enable_zapier',
						'class'             => array( 'ur-enhanced-select' ),
						'custom_attributes' => array(),
						'default'           => ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false ),
						'tip'               => __( 'Enable zapier to integrate user registration with other apps.', 'user-registration-zapier' ),
					),
					array(
						'type'              => 'text',
						'label'             => __( 'Webhook URL', 'user-registration-zapier' ),
						'description'       => '',
						'required'          => false,
						'id'                => 'user_registration_zapier_webhook_url',
						'class'             => array( 'ur-enhanced-select' ),
						'custom_attributes' => array(),
						'default'           => ur_get_single_post_meta( $form_id, 'user_registration_zapier_webhook_url', '' ),
						'tip'               => __( 'Enter a webhook url.', 'user-registration-stripe' ),
					),
					array(
						'type'              => 'checkbox',
						'label'             => __( 'Trigger hook only after user approval', 'user-registration-zapier' ),
						'description'       => '',
						'required'          => false,
						'id'                => 'user_registration_zapier_need_user_approval',
						'class'             => array( 'ur-enhanced-select' ),
						'custom_attributes' => array(),
						'default'           => ur_get_single_post_meta( $form_id, 'user_registration_zapier_need_user_approval', false ),
						'tip'               => __( 'Send data only after user approval or email confirmation. If not then even user is in pending status data will be send.', 'user-registration-zapier' ),
					),
					array(
						'type'              => 'checkbox',
						'label'             => __( 'Trigger hook on user profile update', 'user-registration-zapier' ),
						'description'       => '',
						'required'          => false,
						'id'                => 'user_registration_zapier_trigger_on_profile_update',
						'class'             => array( 'ur-enhanced-select' ),
						'custom_attributes' => array(),
						'default'           => ur_get_single_post_meta( $form_id, 'user_registration_zapier_trigger_on_profile_update', false ),
						'tip'               => __( 'Send data on user profile update from myaccount page and admin update.', 'user-registration-zapier' ),
					),
					array(
						'type'              => 'checkbox',
						'label'             => __( 'Trigger hook on woocommerce checkout', 'user-registration-zapier' ),
						'description'       => '',
						'required'          => false,
						'id'                => 'user_registration_zapier_trigger_on_checkout',
						'class'             => array( 'ur-enhanced-select' ),
						'custom_attributes' => array(),
						'default'           => ur_get_single_post_meta( $form_id, 'user_registration_zapier_trigger_on_checkout', false ),
						'tip'               => __( 'Send data on user profile update from myaccount page and admin update.', 'user-registration-zapier' ),
					),

				),
			);
			$arguments = apply_filters( 'user_registration_get_zapier_settings', $arguments );

			return $arguments['setting_data'];
		}

		/**
		 * Save Zapier Form Settings
		 *
		 * @param  array   $settings Settings.
		 * @param  integer $form_id Form Id.
		 * @return array $settings
		 */
		public function save_zapier_settings( $settings, $form_id = 0 ) {

			$zapier_setting = $this->zapier_form_settings( $form_id );
			$settings       = array_merge( $settings, $zapier_setting );

			return $settings;
		}

		/**
		 * Trigger hook After Admin Approval
		 *
		 * @param int $user_id User ID.
		 */
		public function ur_zapier_after_admin_approval( $user_id ) {
			$form_id          = ur_get_form_id_by_userid( $user_id );
			$is_need_approval = ur_get_single_post_meta( $form_id, 'user_registration_zapier_need_user_approval', false );
			$is_enable_zapier = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );

			if ( 'admin_approval' !== ur_get_single_post_meta( $form_id, 'user_registration_form_setting_login_options', get_option( 'user_registration_general_setting_login_options', 'default' ) ) ) {
				return;
			}
			if ( $is_enable_zapier && $is_need_approval ) {
				ur_zapier_trigger_after_approval( $user_id, $form_id );
			}
		}

		/**
		 * Trigger hook on update user from admin side.
		 *
		 * @param int   $user_id User ID.
		 * @param array $profile Form Details.
		 */
		public function ur_zapier_after_admin_save_profile_validation( $user_id, $profile ) {

			if ( isset( $_POST['ur_user_user_status'] ) && 1 != $_POST['ur_user_user_status'] ) {
				return;
			}

			$form_id                   = get_user_meta( $user_id, 'ur_form_id', true );
			$is_enable_zapier          = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );
			$trigger_on_update_enabled = ur_get_single_post_meta( $form_id, 'user_registration_zapier_trigger_on_profile_update', false );

			if ( $is_enable_zapier && $trigger_on_update_enabled ) {
				$valid_form_data = array();

				foreach ( $_POST as $post_key => $post_data ) {

					$pos = strpos( $post_key, 'user_registration_' );

					if ( false !== $pos ) {
						$new_string = substr_replace( $post_key, '', $pos, strlen( 'user_registration_' ) );

						if ( ! empty( $new_string ) ) {
							$valid_form_data[ $new_string ]               = new stdClass();
							$valid_form_data[ $new_string ]->value        = $post_data;
							$valid_form_data[ $new_string ]->field_type   = $profile[ $post_key ]['type'];
							$valid_form_data[ $new_string ]->label        = $profile[ $post_key ]['label'];
							$valid_form_data[ $new_string ]->field_name   = $new_string;
							$valid_form_data[ $new_string ]->extra_params = array(
								'field_key' => $profile[ $post_key ]['field_key'],
								'label'     => $profile[ $post_key ]['label'],
							);
						}
					} else {

						$key        = 'email' === $post_key ? 'user_email' : $post_key;
						$field_data = 'user_registration_' . $key;
						$data       = isset( $profile[ $field_data ] ) ? $profile[ $field_data ] : array();

						if ( ! empty( $data ) ) {
							$valid_form_data[ $key ]               = new stdClass();
							$valid_form_data[ $key ]->value        = $post_data;
							$valid_form_data[ $key ]->field_type   = $profile[ $field_data ]['type'];
							$valid_form_data[ $key ]->label        = $profile[ $field_data ]['label'];
							$valid_form_data[ $key ]->field_name   = $key;
							$valid_form_data[ $key ]->extra_params = array(
								'field_key' => $profile[ $field_data ]['field_key'],
								'label'     => $profile[ $field_data ]['label'],
							);
						}
					}
				}

				if ( count( $valid_form_data ) < 1 ) {
					return;
				}
				ur_zapier_trigger_data( $valid_form_data, $form_id, $user_id );
			}
		}

	}
}
